==> members-facade-threetree-1.0-20250917.031525-76-sources.jar: com/bizvane/members/facade/vo/MemberInfoVo.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.po.MbrLabelDefPO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/7/13.
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class MemberInfoVo extends MemberInfoModel {

    @ApiModelProperty(value = "扩展属性列表", name = "extendPropertyList")
    private List<ExtendPropertyValueVO> extendPropertyList;

    @ApiModelProperty(value = "会员所属门店编号", name = "memberStoreCode")
    private String memberStoreCode;

    @ApiModelProperty(value = "会员所属门店", name = "memberStoreName")
    private String memberStoreName;

    @ApiModelProperty(value = "会员开卡门店", name = "memberOpenStoreName")
    private String memberOpenStoreName;

    @ApiModelProperty(value = "开卡渠道名称", name = "openCardChannelName")
    private String openCardChannelName;

    @ApiModelProperty(value = "会员所属导购工号", name = "memberGuideCode")
    private String memberGuideCode;

    @ApiModelProperty(value = "会员所属导购", name = "memberGuideName")
    private String memberGuideName;

    @ApiModelProperty(value = "会员所属群组编号", name = "memberStoreGroupCode")
    private String memberStoreGroupCode;

    @ApiModelProperty(value = "会员所属群组", name = "memberStoreGroupName")
    private String memberStoreGroupName;

    @ApiModelProperty(value = "会员所属线上组织code", name = "memberOrgCode")
    private String memberOrgCode;

    @ApiModelProperty(value = "会员所属线上组织名称", name = "memberOrgName")
    private String memberOrgName;

    @ApiModelProperty(value = "会员所属品牌", name = "brandName")
    private String brandName;

    @ApiModelProperty(value = "微信昵称", name = "wxNick")
    private String wxNick;

    @ApiModelProperty(value = "是否关注,1：未关注,2：已关注", name = "focus", example = "是否关注,1：未关注,2：已关注")
    private Integer focus;

    @ApiModelProperty(value = "关注时间", name = "focusTime")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", locale = "zh", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date focusTime;

    @ApiModelProperty(value = "会员标签",name = "labelNames")
    private String labelNames;

    @ApiModelProperty(value = "是否具有品牌邮箱配置",name = "isBrandEmailConfig")
    private Boolean isBrandEmailConfig;

    @ApiModelProperty(value = "所属门店城市", name = "storeCityName")
    private String storeCityName;

    @ApiModelProperty(value = "所属门店区域", name = "storeAreaName")
    private String storeAreaName;

    @ApiModelProperty(value = "会员成长值",name = "growthNum")
    private Integer growthNum;

    @ApiModelProperty(value = "会员开卡门店code", name = "openServiceCode")
    private String openStoreCode;

    @ApiModelProperty(value = "会员开卡门店名称", name = "openServiceName")
    private String openStoreName;

    @ApiModelProperty(value = "会员开卡导购名称", name = "openGuideName")
    private String openGuideName;

    @ApiModelProperty(value = "最近购买时间", name = "lastBuyTime")
    private Date lastBuyTime;

    @ApiModelProperty(value = "打标签时间", name = "labelCreateTime")
    private String labelCreateTime;

    @ApiModelProperty(value = "标签详情", name = "labelList")
    private List<MbrLabelDefPO> labelList;

    @ApiModelProperty(value = "自定义标签列表", name = "mbrCustomLabelList")
    private List<MbrLabelDefPO> mbrCustomLabelList;

    @ApiModelProperty(value = "自动标签列表(事业部标签)", name = "autoLabelList")
    private List<String> autoLabelList;

    @ApiModelProperty(value = "新官方标签名称（重复标签带分组名）", name = "newLabelNames")
    private String newLabelNames;
    
    @ApiModelProperty(value = "即将到期积分", name = "aboutExpireIntegral", example = "即将到期积分")
    private Integer aboutExpireIntegral;

    @ApiModelProperty(value = "即将到期时间", name = "aboutExpireTime", example = "即将到期时间")
    private Date aboutExpireTime;

    @ApiModelProperty(value = "加企微好友时间", name = "addQywxFriendDate")
    private Date addQywxFriendDate;

    @ApiModelProperty(value = "邀请人会员卡号", name = "recommendMemberCardNo")
    private String recommendMemberCardNo;

    @ApiModelProperty(value = "邀请人会员姓名", name = "recommendMemberName")
    private String recommendMemberName;

    @ApiModelProperty(value = "会员erpId列表", name = "erpIdList")
    private List<String> erpIdList;

    @ApiModelProperty(value = "会员memberCodeList列表", name = "memberCodeList")
    private List<String> memberCodeList;

    /**
     * 按会员信息更新时间查询时的开始时间
     */
    private Date startTime;

    /**
     * 按会员信息更新时间查询时的结束时间
     */
    private Date endTime;

    private String openCardStoreCode;
    private String openCardGuideCode;
    private String bindCardChannelName;
    /**
     * 邀请人会员Code
     */
    private String recommendMemberCode;

    /**
     * 邀请人会员卡号
     */
    private String recommendCardNo;

    /**
     * 预计降级时间
     */
    private Date downgradeDate;


}

==> members-facade-threetree-1.0-20250922.075244-82-sources.jar: com/bizvane/members/facade/vo/MemberInfoVo.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.po.MbrLabelDefPO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailConstructabilityRespVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/7/13.
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class MemberInfoVo extends MemberInfoModel {

    @ApiModelProperty(value = "扩展属性列表", name = "extendPropertyList")
    private List<ExtendPropertyValueVO> extendPropertyList;

    @ApiModelProperty(value = "会员所属门店编号", name = "memberStoreCode")
    private String memberStoreCode;

    @ApiModelProperty(value = "会员所属门店", name = "memberStoreName")
    private String memberStoreName;

    @ApiModelProperty(value = "会员开卡门店", name = "memberOpenStoreName")
    private String memberOpenStoreName;

    @ApiModelProperty(value = "开卡渠道名称", name = "openCardChannelName")
    private String openCardChannelName;

    @ApiModelProperty(value = "会员所属导购工号", name = "memberGuideCode")
    private String memberGuideCode;

    @ApiModelProperty(value = "会员所属导购", name = "memberGuideName")
    private String memberGuideName;

    @ApiModelProperty(value = "会员所属群组编号", name = "memberStoreGroupCode")
    private String memberStoreGroupCode;

    @ApiModelProperty(value = "会员所属群组", name = "memberStoreGroupName")
    private String memberStoreGroupName;

    @ApiModelProperty(value = "会员所属线上组织code", name = "memberOrgCode")
    private String memberOrgCode;

    @ApiModelProperty(value = "会员所属线上组织名称", name = "memberOrgName")
    private String memberOrgName;

    @ApiModelProperty(value = "会员所属品牌", name = "brandName")
    private String brandName;

    @ApiModelProperty(value = "微信昵称", name = "wxNick")
    private String wxNick;

    @ApiModelProperty(value = "是否关注,1：未关注,2：已关注", name = "focus", example = "是否关注,1：未关注,2：已关注")
    private Integer focus;

    @ApiModelProperty(value = "关注时间", name = "focusTime")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", locale = "zh", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date focusTime;

    @ApiModelProperty(value = "会员标签",name = "labelNames")
    private String labelNames;

    @ApiModelProperty(value = "是否具有品牌邮箱配置",name = "isBrandEmailConfig")
    private Boolean isBrandEmailConfig;

    @ApiModelProperty(value = "所属门店城市", name = "storeCityName")
    private String storeCityName;

    @ApiModelProperty(value = "所属门店区域", name = "storeAreaName")
    private String storeAreaName;

    @ApiModelProperty(value = "会员成长值",name = "growthNum")
    private Integer growthNum;

    @ApiModelProperty(value = "会员开卡门店code", name = "openServiceCode")
    private String openStoreCode;

    @ApiModelProperty(value = "会员开卡门店名称", name = "openServiceName")
    private String openStoreName;

    @ApiModelProperty(value = "会员开卡导购名称", name = "openGuideName")
    private String openGuideName;

    @ApiModelProperty(value = "最近购买时间", name = "lastBuyTime")
    private Date lastBuyTime;

    @ApiModelProperty(value = "打标签时间", name = "labelCreateTime")
    private String labelCreateTime;

    @ApiModelProperty(value = "标签详情", name = "labelList")
    private List<MbrLabelDefPO> labelList;

    @ApiModelProperty(value = "自定义标签列表", name = "mbrCustomLabelList")
    private List<MbrLabelDefPO> mbrCustomLabelList;

    @ApiModelProperty(value = "自动标签列表(事业部标签)", name = "autoLabelList")
    private List<String> autoLabelList;

    @ApiModelProperty(value = "新官方标签名称（重复标签带分组名）", name = "newLabelNames")
    private String newLabelNames;
    
    @ApiModelProperty(value = "即将到期积分", name = "aboutExpireIntegral", example = "即将到期积分")
    private Integer aboutExpireIntegral;

    @ApiModelProperty(value = "即将到期时间", name = "aboutExpireTime", example = "即将到期时间")
    private Date aboutExpireTime;

    @ApiModelProperty(value = "加企微好友时间", name = "addQywxFriendDate")
    private Date addQywxFriendDate;

    @ApiModelProperty(value = "邀请人会员卡号", name = "recommendMemberCardNo")
    private String recommendMemberCardNo;

    @ApiModelProperty(value = "邀请人会员姓名", name = "recommendMemberName")
    private String recommendMemberName;

    @ApiModelProperty(value = "会员erpId列表", name = "erpIdList")
    private List<String> erpIdList;

    @ApiModelProperty(value = "会员memberCodeList列表", name = "memberCodeList")
    private List<String> memberCodeList;

    /**
     * 按会员信息更新时间查询时的开始时间
     */
    private Date startTime;

    /**
     * 按会员信息更新时间查询时的结束时间
     */
    private Date endTime;

    private String openCardStoreCode;
    private String openCardGuideCode;
    private String bindCardChannelName;
    /**
     * 邀请人会员Code
     */
    private String recommendMemberCode;

    /**
     * 邀请人会员卡号
     */
    private String recommendCardNo;

    /**
     * 预计降级时间
     */
    private Date downgradeDate;

    /**
     * 施工能力
     */
    private List<GetDetailConstructabilityRespVO> constructabilityList;


}
